@@ -10,7 +10,7 @@ import numpy as np
 
 from mmpose.apis import (get_track_id, inference_top_down_pose_model,
                          init_pose_model, vis_pose_result)
-from mmpose.core import apply_bugeye_effect, apply_sunglasses_effect
+from mmpose.core import Smoother, apply_bugeye_effect, apply_sunglasses_effect
 from mmpose.utils import StopWatch
 
 try:
@@ -32,13 +32,15 @@ def parse_args():
     parser.add_argument(
         '--det-config',
         type=str,
-        default='demo/mmdetection_cfg/yolov3_d53_320_273e_coco.py',
+        default='demo/mmdetection_cfg/'
+        'ssdlite_mobilenetv2_scratch_600e_coco.py',
         help='Config file for detection')
     parser.add_argument(
         '--det-checkpoint',
         type=str,
-        default='https://download.openmmlab.com/mmdetection/v2.0/yolo/'
-        'yolov3_d53_320_273e_coco/yolov3_d53_320_273e_coco-421362b6.pth',
+        default='https://download.openmmlab.com/mmdetection/v2.0/ssd/'
+        'ssdlite_mobilenetv2_scratch_600e_coco/ssdlite_mobilenetv2_'
+        'scratch_600e_coco_20210629_110627-974d9307.pth',
         help='Checkpoint file for detection')
     parser.add_argument(
         '--enable-human-pose',
@@ -48,19 +50,20 @@ def parse_args():
     parser.add_argument(
         '--enable-animal-pose',
         type=int,
-        default=1,
+        default=0,
         help='Enable animal pose estimation')
     parser.add_argument(
         '--human-pose-config',
         type=str,
-        default='configs/body/2d_kpt_sview_rgb_img/topdown_heatmap/coco/'
-        'hrnet_w48_coco_256x192.py',
+        default='configs/wholebody/2d_kpt_sview_rgb_img/topdown_heatmap/'
+        'coco-wholebody/vipnas_res50_coco_wholebody_256x192_dark.py',
         help='Config file for human pose')
     parser.add_argument(
         '--human-pose-checkpoint',
         type=str,
-        default='https://download.openmmlab.com/mmpose/top_down/hrnet/'
-        'hrnet_w48_coco_256x192-b9e0b3ab_20200708.pth',
+        default='https://download.openmmlab.com/'
+        'mmpose/top_down/vipnas/'
+        'vipnas_res50_wholebody_256x192_dark-67c0ce35_20211112.pth',
         help='Checkpoint file for human pose')
     parser.add_argument(
         '--human-det-ids',
@@ -99,12 +102,10 @@ def parse_args():
     parser.add_argument(
         '--kpt-thr', type=float, default=0.3, help='bbox score threshold')
     parser.add_argument(
-        '--show-pose',
-        type=lambda s: s != 'False',
-        default=True,
-        choices=['True', 'False'],
-        help='Show pose estimation results. Set False to disable the pose'
-        'visualization. Default: True')
+        '--vis-mode',
+        type=int,
+        default=2,
+        help='0-none. 1-detection only. 2-detection and pose.')
     parser.add_argument(
         '--sunglasses', action='store_true', help='Apply `sunglasses` effect.')
     parser.add_argument(
@@ -127,7 +128,7 @@ def parse_args():
         type=int,
         default=-1,
         help='Frame buffer size. If set -1, the buffer size will be '
-        'automatically inferred from the display delay time. Deafult: -1')
+        'automatically inferred from the display delay time. Default: -1')
 
     parser.add_argument(
         '--inference-fps',
@@ -151,6 +152,18 @@ def parse_args():
         help='Enable synchronous mode that video I/O and inference will be '
         'temporally aligned. Note that this will reduce the display FPS.')
 
+    parser.add_argument(
+        '--smooth',
+        action='store_true',
+        help='Apply a temporal filter to smooth the pose estimation results. '
+        'See also --smooth-filter-cfg.')
+    parser.add_argument(
+        '--smooth-filter-cfg',
+        type=str,
+        default='configs/_base_/filters/one_euro.py',
+        help='Config file of the filter to smooth the pose estimation '
+        'results. See also --smooth.')
+
     return parser.parse_args()
 
 
@@ -167,6 +180,9 @@ def process_mmdet_results(mmdet_results, class_names=None, cat_ids=1):
     if isinstance(mmdet_results, tuple):
         mmdet_results = mmdet_results[0]
 
+    if isinstance(class_names, str):
+        class_names = (class_names, )
+
     if not isinstance(cat_ids, (list, tuple)):
         cat_ids = [cat_ids]
 
@@ -261,8 +277,9 @@ def inference_pose():
             ts_input, frame, t_info, mmdet_results = det_result_queue.popleft()
 
         pose_results_list = []
-        for model_info, pose_history in zip(pose_model_list,
-                                            pose_history_list):
+        for model_info, pose_history, smoother in zip(pose_model_list,
+                                                      pose_history_list,
+                                                      pose_smoother_list):
             model_name = model_info['name']
             pose_model = model_info['model']
             cat_ids = model_info['cat_ids']
@@ -291,9 +308,10 @@ def inference_pose():
                     pose_results_last,
                     next_id,
                     use_oks=False,
-                    tracking_thr=0.3,
-                    use_one_euro=True,
-                    fps=None)
+                    tracking_thr=0.3)
+
+                if smoother:
+                    pose_results = smoother.smooth(pose_results)
 
                 pose_results_list.append(pose_results)
 
@@ -363,7 +381,17 @@ def display():
                     dataset_name = pose_model.cfg.data['test']['type']
 
                     # show pose results
-                    if args.show_pose:
+                    if args.vis_mode == 1:
+                        img = vis_pose_result(
+                            pose_model,
+                            img,
+                            pose_results,
+                            radius=4,
+                            thickness=2,
+                            dataset=dataset_name,
+                            kpt_score_thr=1e7,
+                            bbox_color=bbox_color)
+                    elif args.vis_mode == 2:
                         img = vis_pose_result(
                             pose_model,
                             img,
@@ -376,7 +404,10 @@ def display():
 
                     # sunglasses effect
                     if args.sunglasses:
-                        if dataset_name == 'TopDownCocoDataset':
+                        if dataset_name in {
+                                'TopDownCocoDataset',
+                                'TopDownCocoWholeBodyDataset'
+                        }:
                             left_eye_idx = 1
                             right_eye_idx = 2
                         elif dataset_name == 'AnimalPoseDataset':
@@ -398,7 +429,10 @@ def display():
                                                       right_eye_idx)
                     # bug-eye effect
                     if args.bugeye:
-                        if dataset_name == 'TopDownCocoDataset':
+                        if dataset_name in {
+                                'TopDownCocoDataset',
+                                'TopDownCocoWholeBodyDataset'
+                        }:
                             left_eye_idx = 1
                             right_eye_idx = 2
                         elif dataset_name == 'AnimalPoseDataset':
@@ -461,7 +495,7 @@ def display():
             elif keyboard_input == ord('b'):
                 args.bugeye = not args.bugeye
             elif keyboard_input == ord('v'):
-                args.show_pose = not args.show_pose
+                args.vis_mode = (args.vis_mode + 1) % 3
 
     cv2.destroyAllWindows()
     if vid_out is not None:
@@ -477,6 +511,7 @@ def main():
     global pose_result_queue, pose_result_queue_mutex
     global det_model, pose_model_list, pose_history_list
     global event_exit, event_inference_done
+    global pose_smoother_list
 
     args = parse_args()
 
@@ -520,6 +555,16 @@ def main():
     for _ in range(len(pose_model_list)):
         pose_history_list.append({'pose_results_last': [], 'next_id': 0})
 
+    # build pose smoother for temporal refinement
+    pose_smoother_list = []
+    for _ in range(len(pose_model_list)):
+        if args.smooth:
+            smoother = Smoother(
+                filter_cfg=args.smooth_filter_cfg, keypoint_dim=2)
+        else:
+            smoother = None
+        pose_smoother_list.append(smoother)
+
     # frame buffer
     if args.buffer_size > 0:
         buffer_size = args.buffer_size
