@@ -128,8 +128,8 @@ def _get_area(results):
     """
     for result in results:
         if 'bbox' in result:
-            result['area'] = np.abs((result['bbox'][1] - result['bbox'][0]) *
-                                    (result['bbox'][2] - result['bbox'][3]))
+            result['area'] = ((result['bbox'][2] - result['bbox'][0]) *
+                              (result['bbox'][3] - result['bbox'][1]))
         else:
             xmin = np.min(
                 result['keypoints'][:, 0][result['keypoints'][:, 0] > 0],
@@ -177,8 +177,9 @@ def get_track_id(results,
     Args:
         results (list[dict]): The bbox & pose results of the current frame
             (bbox_result, pose_result).
-        results_last (list[dict]): The bbox & pose & track_id info of the
-            last frame (bbox_result, pose_result, track_id).
+        results_last (list[dict], optional): The bbox & pose & track_id info
+            of the last frame (bbox_result, pose_result, track_id). None is
+            equivalent to an empty result list. Default: None
         next_id (int): The track id for the new person instance.
         min_keypoints (int): Minimum number of keypoints recognized as person.
             default: 3.
@@ -194,6 +195,18 @@ def get_track_id(results,
             current frame (bbox_result, pose_result, track_id).
         - next_id (int): The track id for the new person instance.
     """
+    if use_one_euro:
+        warnings.warn(
+            'In the future, get_track_id() will no longer perform '
+            'temporal refinement and the arguments `use_one_euro` and '
+            '`fps` will be deprecated. This part of function has been '
+            'migrated to Smoother (mmpose.core.Smoother). See '
+            'demo/top_down_pose_trackign_demo_with_mmdet.py for an '
+            'example.', DeprecationWarning)
+
+    if results_last is None:
+        results_last = []
+
     results = _get_area(results)
 
     if use_oks:
@@ -216,6 +229,7 @@ def get_track_id(results,
                 result['track_id'] = -1
         else:
             result['track_id'] = track_id
+
         if use_one_euro:
             result['keypoints'] = _temporal_refine(
                 result, match_result, fps=fps)
