@@ -175,9 +175,8 @@ class Kpt2dSviewRgbImgTopDownDataset(Dataset, metaclass=ABCMeta):
         raise NotImplementedError
 
     @abstractmethod
-    def evaluate(self, cfg, outputs, res_folder, metric, *args, **kwargs):
+    def evaluate(self, results, *args, **kwargs):
         """Evaluate keypoint results."""
-        raise NotImplementedError
 
     @staticmethod
     def _write_keypoint_results(keypoints, res_file):
