@@ -1,11 +1,13 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 import os
 import os.path as osp
+import tempfile
 import warnings
 from collections import OrderedDict, defaultdict
 
 import json_tricks as json
 import numpy as np
+from mmcv import deprecated_api_warning
 
 from ....core.post_processing import oks_nms, soft_oks_nms
 from ...builder import DATASETS
@@ -184,8 +186,7 @@ class TopDownPoseTrack18VideoDataset(Kpt2dSviewRgbVidTopDownDataset):
             center, scale = self._xywh2cs(*obj['clean_bbox'][:4])
 
             image_files = []
-            cur_image_file = os.path.join(self.img_prefix,
-                                          self.id2name[img_id])
+            cur_image_file = osp.join(self.img_prefix, self.id2name[img_id])
             image_files.append(cur_image_file)
 
             # "images/val/012834_mpii_test/000000.jpg" -->> "000000.jpg"
@@ -211,11 +212,12 @@ class TopDownPoseTrack18VideoDataset(Kpt2dSviewRgbVidTopDownDataset):
                     cur_image_name,
                     str(support_idx).zfill(self.ph_fill_len) + '.jpg')
 
-                if os.path.exists(sup_image_file):
+                if osp.exists(sup_image_file):
                     image_files.append(sup_image_file)
                 else:
-                    warnings.warn(f'{sup_image_file} does not exist, '
-                                  f'use {cur_image_file} instead.')
+                    warnings.warn(
+                        f'{sup_image_file} does not exist, '
+                        f'use {cur_image_file} instead.', UserWarning)
                     image_files.append(cur_image_file)
             rec.append({
                 'image_file': image_files,
@@ -284,7 +286,7 @@ class TopDownPoseTrack18VideoDataset(Kpt2dSviewRgbVidTopDownDataset):
             else:
                 file_name = self.id2name[det_res['image_id']]
 
-            cur_image_file = os.path.join(self.img_prefix, file_name)
+            cur_image_file = osp.join(self.img_prefix, file_name)
             image_files.append(cur_image_file)
 
             # "images/val/012834_mpii_test/000000.jpg" -->> "000000.jpg"
@@ -302,7 +304,7 @@ class TopDownPoseTrack18VideoDataset(Kpt2dSviewRgbVidTopDownDataset):
                     cur_image_name,
                     str(support_idx).zfill(self.ph_fill_len) + '.jpg')
 
-                if os.path.exists(sup_image_file):
+                if osp.exists(sup_image_file):
                     image_files.append(sup_image_file)
                 else:
                     warnings.warn(f'{sup_image_file} does not exist, '
@@ -332,7 +334,8 @@ class TopDownPoseTrack18VideoDataset(Kpt2dSviewRgbVidTopDownDataset):
               f'low score@{self.det_bbox_thr}: {bbox_id}')
         return kpt_db
 
-    def evaluate(self, outputs, res_folder, metric='mAP', **kwargs):
+    @deprecated_api_warning(name_dict=dict(outputs='results'))
+    def evaluate(self, results, res_folder=None, metric='mAP', **kwargs):
         """Evaluate posetrack keypoint results. The pose prediction results
         will be saved in ``${res_folder}/result_keypoints.json``.
 
@@ -340,7 +343,8 @@ class TopDownPoseTrack18VideoDataset(Kpt2dSviewRgbVidTopDownDataset):
             - num_keypoints: K
 
         Args:
-            outputs (list[dict]): Outputs containing the following items.
+            results (list[dict]): Testing results containing the following
+                items:
 
                 - preds (np.ndarray[N,K,3]): The first two dimensions are \
                     coordinates, score is the third dimension of the array.
@@ -350,7 +354,9 @@ class TopDownPoseTrack18VideoDataset(Kpt2dSviewRgbVidTopDownDataset):
                     /000024.jpg']
                 - heatmap (np.ndarray[N, K, H, W]): model output heatmap.
                 - bbox_id (list(int))
-            res_folder (str): Path of directory to save the results.
+            res_folder (str, optional): The folder to save the testing
+                results. If not specified, a temp folder will be created.
+                Default: None.
             metric (str | list[str]): Metric to be performed. Defaults: 'mAP'.
 
         Returns:
@@ -362,19 +368,23 @@ class TopDownPoseTrack18VideoDataset(Kpt2dSviewRgbVidTopDownDataset):
             if metric not in allowed_metrics:
                 raise KeyError(f'metric {metric} is not supported')
 
-        pred_folder = osp.join(res_folder, 'preds')
-        os.makedirs(pred_folder, exist_ok=True)
+        if res_folder is not None:
+            tmp_folder = None
+        else:
+            tmp_folder = tempfile.TemporaryDirectory()
+            res_folder = tmp_folder.name
+
         gt_folder = osp.join(
             osp.dirname(self.ann_file),
             osp.splitext(self.ann_file.split('_')[-1])[0])
 
         kpts = defaultdict(list)
 
-        for output in outputs:
-            preds = output['preds']
-            boxes = output['boxes']
-            image_paths = output['image_paths']
-            bbox_ids = output['bbox_ids']
+        for result in results:
+            preds = result['preds']
+            boxes = result['boxes']
+            image_paths = result['image_paths']
+            bbox_ids = result['bbox_ids']
 
             batch_size = len(image_paths)
             for i in range(batch_size):
@@ -425,11 +435,14 @@ class TopDownPoseTrack18VideoDataset(Kpt2dSviewRgbVidTopDownDataset):
             else:
                 valid_kpts[image_id].append(img_kpts)
 
-        self._write_keypoint_results(valid_kpts, gt_folder, pred_folder)
+        self._write_keypoint_results(valid_kpts, gt_folder, res_folder)
 
-        info_str = self._do_keypoint_eval(gt_folder, pred_folder)
+        info_str = self._do_keypoint_eval(gt_folder, res_folder)
         name_value = OrderedDict(info_str)
 
+        if tmp_folder is not None:
+            tmp_folder.cleanup()
+
         return name_value
 
     @staticmethod
